AppDesignTokens class final

Annotations

Constructors

AppDesignTokens({required AppColorTokens colors, AppSpacingTokens spacing = AppSpacingTokens.regular, AppRadiusTokens radius = AppRadiusTokens.regular, AppSizeTokens sizes = AppSizeTokens.regular, AppMotionTokens motion = AppMotionTokens.regular, AppTypographyTokens typography = AppTypographyTokens.regular})
const

Properties

colors AppColorTokens
final
hashCode int
The hash code for this object.
no setterinherited
motion AppMotionTokens
final
radius AppRadiusTokens
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizes AppSizeTokens
final
spacing AppSpacingTokens
final
typography AppTypographyTokens
final

Methods

copyWith({AppColorTokens? colors, AppSpacingTokens? spacing, AppRadiusTokens? radius, AppSizeTokens? sizes, AppMotionTokens? motion, AppTypographyTokens? typography}) AppDesignTokens
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

dark → const AppDesignTokens
light → const AppDesignTokens